from mfasweep import mfasweep
import sys

mfasweep.main(sys.argv)